#!/usr/bin/python
# -*- coding: utf-8 -*-

from enigma import getDesktop, ePoint, eSize
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from skin import parseColor
from Screens.ChannelSelection import ChannelSelection, ChannelSelectionBase
import Screens.InfoBarGenerics
from Screens.InfoBar import InfoBar
from Screens.Setup import SetupSummary
from Components.ActionMap import ActionMap
from Components.Sources.StaticText import StaticText
from Components.Label import Label
from Components.ConfigList import ConfigListScreen
from Components.config import * 

PluginVersion = ""

sz_w = getDesktop(0).size().width()
csel = ChannelSelection

class PiPChannelSelectionSetup(Screen, ConfigListScreen):
	
	if sz_w == 1920:
		skin = """
		<screen name="PiPChannelSelectionSetup" position="center,center" size="1200,820">
			<ePixmap pixmap="skin_default/buttons/red.png" position="10,5" size="295,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="305,5" size="295,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="600,5" size="295,70" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="895,5" size="295,70" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="10,5" zPosition="1" size="295,70" font="Regular;30" halign="center" valign="center" backgroundColor="#9f1313" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget source="key_green" render="Label" position="310,5" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" backgroundColor="#1f771f" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget source="key_yellow" render="Label" position="610,5" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" backgroundColor="#9f1313" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget source="key_blue" render="Label" position="910,5" zPosition="1" size="300,70" font="Regular;30" halign="center" valign="center" backgroundColor="#1f771f" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget name="config" position="10,90" size="1180,540" enableWrapAround="1" scrollbarMode="showOnDemand" />
			<ePixmap pixmap="skin_default/div-h.png" position="10,650" zPosition="2" size="1180,2" />
			<widget name="help" position="10,655" size="1180,145" font="Regular;32" />
		</screen>"""
	else:
		skin = """
		<screen name="PiPChannelSelectionSetup" position="center,center" size="800,530">
			<ePixmap pixmap="skin_default/buttons/red.png" position="0,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/green.png" position="200,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/yellow.png" position="400,0" size="200,40" scale="stretch" alphatest="on" />
			<ePixmap pixmap="skin_default/buttons/blue.png" position="600,0" size="200,40" scale="stretch" alphatest="on" />
			<widget source="key_red" render="Label" position="0,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#9f1313" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget source="key_green" render="Label" position="200,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#1f771f" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget source="key_yellow" render="Label" position="400,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#9f1313" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget source="key_blue" render="Label" position="600,0" zPosition="1" size="200,40" font="Regular;22" halign="center" valign="center" backgroundColor="#1f771f" shadowColor="black" shadowOffset="-2,-2" transparent="1" />
			<widget name="config" position="5,50" size="790,380" enableWrapAround="1" scrollbarMode="showOnDemand" />
			<ePixmap pixmap="skin_default/div-h.png" position="0,431" zPosition="2" size="800,2" />
			<widget name="help" position="5,435" size="790,75" font="Regular;22" />
		</screen>"""


	def __init__(self, session):
		Screen.__init__(self, session)

		# Summary
		global PluginVersion
		from plugin import VERSION
		PluginVersion = VERSION
		self.skinName = "PiPChannelSelectionSetup"
		self.setup_title = _("PiPChannelSelection Setup ") + str(PluginVersion)
		self.onChangedEntry = []
		
		self.list = []
		self.buildConfig()
		ConfigListScreen.__init__(self, self.list, session = session, on_change = self.changed)
		
		def selectionChanged():
			if self["config"].current:
				self["config"].current[1].onDeselect(self.session)
			self["config"].current = self["config"].getCurrent()
			if self["config"].current:
				self["config"].current[1].onSelect(self.session)
			for x in self["config"].onSelectionChanged:
				x()
		self["config"].selectionChanged = selectionChanged
		self["config"].onSelectionChanged.append(self.updateHelp)

		# Initialize widgets
		self["key_green"] = StaticText(_("OK"))
		self["key_red"] = StaticText(_("Cancel"))
		self["key_yellow"] = StaticText("MoveResizePiP")
		self["key_blue"] = StaticText("")
		self["help"] = Label("")
		
		# Define Actions
		self["actions"] = ActionMap(["SetupActions", "ColorActions"],
			{
				"cancel": 	self.keyCancel,
				"save": 		self.save,
				"yellow":		self.MoveResizePiP,
				#"save": 		self.keySave,
			},-2)

		# Trigger change
		self.changed()

		self.onLayoutFinish.append(self.layoutFinished)

	def buildConfig(self):
		
		self.list.append( getConfigListEntry(_("activate PiP for ChannelSelection"), config.plugins.pipchannelselection.enable, _("active the pip-window in the channelselection-screen")) )
		
		if config.plugins.pipchannelselection.enable.value:
			self.list.append( getConfigListEntry(_("show PiP automatically on open ChannelSelection"), config.plugins.pipchannelselection.autoshow, _("if set to 'yes' the PiP is shown automatically on open ChannelSelection. Otherwise you can open the PiP manually with the 'Play'-Key. You can allways close the PiP with the 'Stop'-Key.")) )
			self.list.append( getConfigListEntry(_("select the x-Position of pip"), config.plugins.pipchannelselection.pipPosX, _("select the position of pip from left (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )
			self.list.append( getConfigListEntry(_("select the top-position of pip"), config.plugins.pipchannelselection.pipPosY, _("select the position of pip from top (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )
			self.list.append( getConfigListEntry(_("select the width of pip"), config.plugins.pipchannelselection.pipSizeWidth, _("select the width of pip (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )
			self.list.append( getConfigListEntry(_("select the height of pip"), config.plugins.pipchannelselection.pipSizeHeight, _("select the height of pip (use this value only if the skin-screen don't have a 'pipvideo'-widget)")) )

	def layoutFinished(self):
		self.setTitle(self.setup_title)

	def setCustomTitle(self):
		self.setTitle(self.setup_title)

	def updateHelp(self):
		cur = self["config"].getCurrent()
		if cur:
			self["help"].text = cur[2]

	def changeConfig(self):
		self.list = []
		self.buildConfig()
		self["config"].setList(self.list)

	def changed(self):
		for x in self.onChangedEntry:
			x()
		current = self["config"].getCurrent()[1]
		if (current == config.plugins.pipchannelselection.enable):
			self.changeConfig()
		return

	def getCurrentEntry(self):
		return self["config"].getCurrent()[0]

	def getCurrentValue(self):
		return str(self["config"].getCurrent()[1].getText())

	def createSummary(self):
		return SetupSummary
	
	def save(self):
		for x in self["config"].list:
			x[1].save()
		self.close()
		
		Screens.InfoBarGenerics.InfoBarChannelSelection.__init__(InfoBar.instance)
		
		#remove multiple __delChannelSelectionScreen in InfoBar.onClose
		try:
			count=0
			for fnc in InfoBar.instance.onClose:
				if fnc == InfoBar.instance._InfoBarChannelSelection__delChannelSelectionScreen:
					count+=1
				if count>1:
					InfoBar.instance.onClose.remove(InfoBar.instance._InfoBarChannelSelection__delChannelSelectionScreen)
					count-=1
		except:
			import traceback
			traceback.print_exc()

	def MoveResizePiP(self):
		self.session.open(ChannelSelectionSetupPiP)


if os_path.exists("/usr/lib/enigma2/python/Plugins/Extensions/ValisEPG") and hasattr(config,"valisepg") and config.valisepg.channellist.value == "valis":
	from Plugins.Extensions.ValisEPG.plugin import ValisEPG
	csel = ValisEPG

class ChannelSelectionSetupPiP(csel):
	def __init__(self, session):
		csel.__init__(self, session)
		self.skinName = csel.__name__
		
		self["actions"] = ActionMap(["PiPSetupActions", "ColorActions", "MenuActions"], 
		{
			"ok": self.save,
			"cancel": self.cancel,
			"up": self.up,
			"down": self.down,
			"left": self.left,
			"right": self.right,
			"size+": self.bigger,
			"size-": self.smaller,
			"red": self.right1,
			"green": self.down1,
			"yellow": self.bigger1,
			"blue": self.smaller1,
			"menu": self.menu,
		}, -1)
		
		self.onLayoutFinish.append(self.layoutFinished)
		
	def onShown_ChannelSelection(self):
		self.onShown.remove(self.onShown_ChannelSelection)
		self.session.open(MessageBox, _("Please use direction keys to move the PiP window.\nPress Bouquet +/- to resize the window.\nPress OK to go back to the TV mode or EXIT to cancel the moving.") + "\n" +_("(use color-buttons to move/resize with smaller steps)"),MessageBox.TYPE_INFO)

	def layoutFinished(self):
		print "=== ChannelSelectionSetupPiP layoutFinished"
		w = int(config.plugins.pipchannelselection.pipSizeWidth.value)
		h = int(config.plugins.pipchannelselection.pipSizeHeight.value)
		x = int(config.plugins.pipchannelselection.pipPosX.value)
		y = int(config.plugins.pipchannelselection.pipPosY.value)
		self["pipvideo"].instance.move(ePoint(x,y))
		self["pipvideo"].instance.resize(eSize(w, h))
		self["pipvideo"].instance.setBackgroundColor(parseColor("#bbffffff"))
		self["pipvideo"].instance.setZPosition(1000)
		self["pipvideo"].instance.invalidate() 
		self["pipvideo"].show()

	def menu(self):
		pass #to ignore Menu

	def save(self):
		print "=== Pos, Size", self["pipvideo"].instance.position().x(), self["pipvideo"].instance.position().y(), self["pipvideo"].instance.size().width(), self["pipvideo"].instance.size().height()
		w = int(config.plugins.pipchannelselection.pipSizeWidth.value)
		h = int(config.plugins.pipchannelselection.pipSizeHeight.value)
		x = int(config.plugins.pipchannelselection.pipPosX.value)
		y = int(config.plugins.pipchannelselection.pipPosY.value)
		print "=== Pos, Size", x,y,w,h
		config.plugins.pipchannelselection.pipSizeWidth.value = self["pipvideo"].instance.size().width()
		config.plugins.pipchannelselection.pipSizeHeight.value = self["pipvideo"].instance.size().height()
		config.plugins.pipchannelselection.pipPosX.value = self["pipvideo"].instance.position().x()
		config.plugins.pipchannelselection.pipPosY.value = self["pipvideo"].instance.position().y()
		
		self.close()

	def up(self):
		self.set_up_down(-16)

	def up1(self):
		self.set_up_down(-1)

	def down(self):
		self.set_up_down(16)
	
	def down1(self):
		self.set_up_down(1)

	def set_up_down(self, value):
		yPos = self["pipvideo"].instance.position().y() + value
		#set new pos if pip is show outside of the screen
		if yPos < 0:
			yPos=0
		if yPos + self["pipvideo"].instance.size().height() > self.instance.size().height():
			yPos = self.instance.size().height() - self["pipvideo"].instance.size().height()
		xPos = self["pipvideo"].instance.position().x()
		self["pipvideo"].instance.move(ePoint(xPos, yPos))
		print "=== up_down", yPos

	def right(self):
		self.set_right_left(12)

	def right1(self):
		self.set_right_left(1)

	def left(self):
		self.set_right_left(-12)

	def left1(self):
		self.set_right_left(-1)

	def set_right_left(self, value):
		xPos = self["pipvideo"].instance.position().x() + value
		#set new pos if pip is show outside of the screen
		if xPos<0:
			xPos=0
		if xPos + self["pipvideo"].instance.size().width() > self.instance.size().width():
			xPos = self.instance.size().width() - self["pipvideo"].instance.size().width()
		self["pipvideo"].instance.move(ePoint(xPos, self["pipvideo"].instance.position().y()))
		print "=== left", xPos

	def bigger(self):
		self.resizePiP(+5)
	
	def smaller(self):
		self.resizePiP(-5)

	def bigger1(self):
		self.resizePiP(+1)
	
	def smaller1(self):
		self.resizePiP(-1)

	def resizePiP(self, resize):
		resize += 100 # resize is in percent, so resize=+20 means: 120%
		oldsize = self["pipvideo"].instance.size()
		size = self["pipvideo"].instance.size()
		w = int(size.width() * resize / 100)
		h = int(size.height() * resize / 100)
		if w > getDesktop(0).size().width()/2 - 10:
			w = getDesktop(0).size().width()/2 - 10
			f = float(w) / size.width()
			h = int(size.height() * f)
		self["pipvideo"].instance.resize(eSize(w, h))
		#set new pos if new size go outside from screen
		if self["pipvideo"].instance.position().x() + self["pipvideo"].instance.size().width() > self.instance.size().width():
			xPos = self.instance.size().width() - self["pipvideo"].instance.size().width()
			self["pipvideo"].instance.move(ePoint(xPos, self["pipvideo"].instance.position().y()))
		if self["pipvideo"].instance.position().y() + self["pipvideo"].instance.size().height() > self.instance.size().height():
			yPos = self.instance.size().height() - self["pipvideo"].instance.size().height()
			self["pipvideo"].instance.move(ePoint(self["pipvideo"].instance.position().x(), yPos))

	def cancel(self):
		self.close()